function [NCSMAX,S,Market,Group]=IMatrix(TALT,NP,XMAT)

global dsm dcs alt mar asymmetry

% Maximum number of choice situations in market
nn=zeros(NP,1);
for n=1:NP;
    k=(XMAT(:,dsm)==n);    %Identifies rows relevant for hh
    k=XMAT(k,dcs);         %Selects choice situations relevant for hh
    nn(n,1)=1+k(end,1)-k(1,1);   %Computes total number of choice situations for hh
end
NCSMAX=max(nn);  %Maximum number of choice situations faced by any person

cp=XMAT(:,dsm);   % person
run=size(XMAT,2); %Column identifying group

%Create matraces containing which choice situation and alternatives are in
%the sample and the corresponding matrix of market indices
S=zeros(TALT,NCSMAX,NP);     % Identification of the relevant alternatives 
%                                 and choice situation, for each person
Market=zeros(TALT,NCSMAX,NP); %TALTxNCSMAXxNP matrix for market 

Group=zeros(TALT,NCSMAX,NP); %TALTxNCSMAXxNP matrix for group

for n=1:NP;  %loop over people
 xm=XMAT(cp == n, mar);   
 xr=XMAT(cp == n, run);   
 cs=XMAT(cp == n,dcs);    %Selects choice situations for hh
  t1=cs(1,1);    %First choice situation
  t2=cs(end,1);  %Final choice situation
  
  if asymmetry==0 %Runs more quickly with identical choice sets
  
   for t=t1:t2; %loop over choice situations
       k=sum(cs==t); %Number of alts 
       S(1:k,1+t-t1,n)=ones(k,1); %Set relevant elements of S matrix to 1
       Market(1:k,1+t-t1,n)=xm(cs==t,:); %Enter relevant elements in market  
       Group(1:k,1+t-t1,n)=xr(cs==t,:); %Enter relevant elements in group 
   end
  else
      
   ops=XMAT(cp == n,alt);    %Selects options for hh
   for t=t1:t2; %loop over choice situations
      cops=ops(cs==t);
      r1=cops(1,1);
      r2=cops(end,1);
      for r=r1:r2 %loop over options
          if sum(cops==r)==1 %skip options not in choice set
              S(r,1+t-t1,n)=1; %Set relevant elements of S matrix to 1
              Market(r,1+t-t1,n)=xm(cs==t & ops==r,:); %Enter relevant elements in market
              Group(r,1+t-t1,n)=xr(cs==t & ops==r,:); %Enter relevant elements in group
          end
      end
   end   
  end   
      
end
