clear

% Declare GLOBAL variables
global NP NCS NROWS
global IDV NV NAMES B W corrc
global IDF NF NAMESF F
global DRAWTYPE NDRAWS SEED1 SAVEDR PUTDR
global WANTWGT IDWGT WGT
global NALTMAX NCSMAX
global X XF S DR MDR
global XMAT
global NMEM NTAKES NPARAM

global dsm dcs choice alt mar OProd OFirm asymmetry
global PV PVI SV SVI CC1 CC2
global DataDir OutDir OutDirOr

Path='C:/DuboisGriffithOConnell.2017.ReStud';

DataDir=fullfile(Path,'Stata_files/Estimation');
OutDir=fullfile(Path,'Matlab_files/MainResults/FoodIn');

%Regression options
ParameterFileReg='runs_fi_main';

%Options common across regressions
ParameterFileEst='parm_fi_main';

eval(ParameterFileReg);
 
%Estimate each model
disp(R);
for i=1:1
   disp(i);
   eval(['NP=NP',int2str(i),';']);
   eval(['NCS=NCS',int2str(i),';']);
   eval(['NROWS=NROWS',int2str(i),';']);
   
   eval(['doestimates(BaseString',int2str(i),',OutString',int2str(i),',ParameterFileEst);']);
end
clear global NCSMAX DR MDR

%Combine coefficients
combine_coeffs(ParameterFileReg,ParameterFileEst);

%Computation options
ParameterFileReg='runs_fi_main_comp';

%Append together data
aggregate=0;    %Set equal to one to append together aggregated data
AllDataFile=fullfile(OutDir,[OutString,'_aggdata.mat']);
combine_data(ParameterFileReg,ParameterFileEst,aggregate,AllDataFile);

% %Compute elasticities and marginal costs 
aggregate=0;
AllDataFile=fullfile(OutDir,[OutString,'_aggdata.mat']);
equilibrium(ParameterFileReg,ParameterFileEst,aggregate,AllDataFile);

%True ownership structure
FirmSimFile=fullfile(DataDir,[BaseString,'_firm_data.raw']);
 
type=1;
SimOut=fullfile(OutDir,[OutString,'simulations.raw']);
SimFile=fullfile(OutDir,[OutString,'eq_price.mat']);
[Outdata,DemanddataNR,DemanddataNE,ConsumerPrice]= ...
    simulation(ParameterFileReg,ParameterFileEst,type,FirmSimFile,[],aggregate,AllDataFile);
save(SimOut,'Outdata','-ascii','-double','-tabs'); 
save(SimFile,'ConsumerPrice');

%Output estimation results
SaveCoefs(ParameterFileReg,ParameterFileEst);

%Compute consumer welfare
type=1;
SimFile=fullfile(OutDir,[OutString,'eq_price.mat']);
aggregate=0;
AllDataFile=fullfile(OutDir,[OutString,'_aggdata.mat']);
ComputeWelfare(ParameterFileReg,ParameterFileEst,type,[],SimFile,aggregate,AllDataFile);

%Compute confidence intervals
bootstrap=1;
REPS=100;
bootfolder='bootstrap_fi';
ParameterFileRegBS='runs_fi_bootstrap';

if bootstrap==1
    drawcoefficients(ParameterFileReg,ParameterFileEst,REPS,bootfolder);
    OutDirOr=OutDir;
    for b=1:REPS
        bf=int2str(b);
        OutDir=fullfile(OutDirOr,bootfolder,bf);
        
        equilibrium(ParameterFileRegBS,ParameterFileEst,aggregate,AllDataFile);
        
        FirmSimFile=fullfile(DataDir,[BaseString,'_firm_data.raw']);

        type=1;
        SimOut=fullfile(OutDir,[OutString,'simulations.raw']);
        SimFile=fullfile(OutDir,[OutString,'eq_price.mat']);
        [Outdata,DemanddataNR,DemanddataNE,ConsumerPrice]= ...
            simulation(ParameterFileRegBS,ParameterFileEst,type,FirmSimFile,[],aggregate,AllDataFile);
        save(SimOut,'Outdata','-ascii','-double','-tabs'); 
        save(SimFile,'ConsumerPrice');

        SaveCoefsBoot(ParameterFileRegBS,ParameterFileEst);
         
        ComputeWelfare(ParameterFileRegBS,ParameterFileEst,type,[],SimFile,aggregate,AllDataFile);
    end
end

