function doit(BaseString,OutString,ParameterFile)

% Declare GLOBAL variables
% GLOBAL variables are all in caps
% DO NOT CHANGE ANY OF THESE 'global' STATEMENTS
global NP NCS NROWS
global IDV NV NAMES B W corrc
global IDF NF NAMESF F
global DRAWTYPE NDRAWS SEED1 SAVEDR PUTDR
global WANTWGT IDWGT WGT
global NALTMAX NCSMAX
global X XF S DR
global XMAT
global NMEM NTAKES NPARAM
global MDR

global dsm dcs choice alt mar OProd OFirm asymmetry
global PV PVI SV SVI CC1 CC2

eval(ParameterFile);
XMAT=load(fullfile(DataDir,[BaseString,'_data.raw'])); 

% If price random coefficient is log normal, negate variables involving
% price
if isempty(IDV)==0
    if sum(IDV(1,:)==PV)>0
        if IDV(find(IDV(1,:)==PV),2)==2
            XMAT(:,PV)= -XMAT(:,PV);
            if isempty(PVI)==0
                XMAT(:,PVI(:,1)')= -XMAT(:,PVI(:,1)');
            end
        end
    end
end

DiaryFile=fullfile(OutDir,[OutString,'.out']);
diary off
delete(DiaryFile)
diary(DiaryFile)
 
% Check the input data and specifications

disp('Checking inputs.');
check;
if ok == 1;
    disp('Inputs have been checked and look fine.');
    clear ok
else
    return;
end

% Create Global variables to use in estimation

disp('Creating data arrays for run.');
cp=XMAT(:,dsm); % person
 
nn=zeros(NCS,1);
for n=1:NCS;
    nn(n,1)=sum(XMAT(:,dcs) == n,1);
end;
NALTMAX=max(nn);  %Maximum number of alternatives in any choice situation

nn=zeros(NP,1);
for n=1:NP;
   k=(XMAT(:,dsm)==n);    %Identifies rows relevant for hh
   k=XMAT(k,dcs);         %Selects choice situations relevant for hh
   nn(n,1)=1+k(end,1)-k(1,1);   %Computes total number of choice situations for hh
end;
NCSMAX=max(nn);  %Maximum number of choice situations faced by any person

NTAKES=NDRAWS./NMEM; %This tells code how many passes through the draws are needed 
                           % given NMEM people in each pass.
if WANTWGT == 1;
    WGT=zeros(1,NP);
    for r=1:NP
        WGT(1,r)=mean(XMAT(cp == r,IDWGT),1);
    end
    WGT=WGT.*(NP./sum(WGT,2));
else
    WGT=[];
end

% Data arrays 
% All variables are differenced from the chosen alternative
% Only nonchosen alternatives are included, since V for chosen alt =0
% This reduces number of calculations for logit prob and eliminates need to
% retain dependent variable.

X=zeros(NALTMAX-1,NCSMAX,NV,NP); % Explanatory variables with random coefficients 
%                                  for all choice situations, for each person 
XF=zeros(NALTMAX-1,NCSMAX,NF,NP); % Explanatory variables with fixed coefficients 
%                                  for all choice situations, for each person 
S=zeros(NALTMAX-1,NCSMAX,NP); % Identification of the relevant alternatives 
                              % and choice situation, for each person

for n=1:NP;  %loop over people
 cs=XMAT(cp == n,dcs);    %Selects choice situations for hh
 yy=XMAT(cp == n,choice);    %Selects alternatives for hh
 if NV > 0
    xx=XMAT(cp == n, IDV(:,1)); %Selects 'random' variables for hh
 end
 if NF > 0
    xxf=XMAT(cp == n, IDF(:,1)); %Selects 'fixed' variables for hh
 end
 t1=cs(1,1);    %First choice situation
 t2=cs(end,1);  %Final choice situation
 for t=t1:t2; %loop over choice situations
     k=sum(cs==t)-1; %One less than number of alts = number of nonchosen alts
     S(1:k,1+t-t1,n)=ones(k,1); %Set relevant elements of S matrix to 1
     if NV>0
        X(1:k,1+t-t1,:,n)=xx(cs==t & yy == 0,:)-repmat(xx(cs==t & yy == 1,:),k,1);
        %Subtract chosen option vars off of non chosen options
     end
     if NF>0
        XF(1:k,1+t-t1,:,n)=xxf(cs==t & yy == 0,:)-repmat(xxf(cs==t & yy == 1,:),k,1);
        %Subtract chosen option vars off of non chosen options
     end;
 end
end


%clear global XMAT 
clear cp cs yy xx t1 t2 k nn
    
randn('state',SEED1)  %For draws from normal
rand('state',SEED1)   %For draws from uniform

%Create draws

if DRAWTYPE ~= 5
   disp('Creating draws.');
   DR=makedraws;   %NMEMxNPxNV matrix of draws
   if NTAKES == 1
      DR=permute(DR,[3,2,1]);   %To make NVxNPxNDRAWS
   else 
      MDR=memmapfile(PUTDR,'Format',{'double',[NDRAWS,NP,NV],'drs'});
   end
end

if corrc==1
    W=zeros(0.5*NV*(NV+1),1);
    x=0;
    L=chol(VC,'lower');
    for i=1:NV
        for j=1:i
            W(x+1)=L(i,j);
            x=x+1;
        end
    end
end

%Set up parameter vector: [fixed, random param1, random param2]
if NV>0 & NF>0
   param=[F;B(IDV(:,2)~=5,1);W];    %Notice param1 is omitted for error comp var
elseif NV>0 & NF==0
   param=[B(IDV(:,2)~=5,1);W];  
elseif NV==0 & NF>0;
   param=F;
else
   disp('Model has no explanatory variables.');
   disp('IDV and IDF are both empty.');
   disp('Program terminated.');
   return
end

test=0;
if test==1
    testloglik(param);
    keyboard
end

disp('Start estimation');
disp('The negative of the log-likelihood is minimized,');
disp('which is the same as maximizing the log-likelihood.');
tic;
options=optimset('LargeScale','off','Display','iter','GradObj','on',...
   'MaxFunEvals',10000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL,'DerivativeCheck','off');
[paramhat,fval,exitflag,output,grad,hessian]=fminunc(@loglik,param,options);

disp(' ');
disp(['Estimation took ' num2str(toc./60) ' minutes.']);
disp(' ');
if exitflag == 1
  disp('Convergence achieved.');
elseif exitflag == 2
  disp('Convergence achieved by criterion based on change in parameters.');
  if size(PARAMTOL,1)>0
     disp(['Parameters changed less than PARAMTOL= ' num2str(PARAMTOL)]);
  else
     disp('Parameters changed less than PARAMTOL=0.000001, set by default.');
  end
  disp('You might want to check whether this is actually convergence.');
  disp('The gradient vector is');
  grad
elseif exitflag == 3
  disp('Convergence achieved by criterion based on change in log-likelihood value.');
  if size(PARAMTOL,1)>0
     disp(['Log-likelihood value changed less than LLTOL= ' num2str(LLTOL)]);
  else
     disp('Log-likelihood changed less than LLTOL=0.000001, set by default.');
  end
     disp('You might want to check whether this is actually convergence.');
     disp('The gradient vector is');
     grad
else
    disp('Convergence not achieved.');
    disp('The current value of the parameters and hessian');
    disp('can be accessed as variables paramhat and hessian.');
    disp('Results are not printed because no convergence.');
    return
end

disp(['Value of the log-likelihood function at convergence: ' num2str(-fval)]);

%Calculate standard errors of parameters
disp(' ');
disp('Taking inverse of hessian for standard errors.');
disp(' ');
ihess=inv(hessian);
disp(['The value of grad*inv(hessian)*grad is: ' num2str(grad'*ihess*grad)]);

if NF>0
  fhat=paramhat(1:NF,1);    %NVX1 vector of optimal fixed coeffs
end

if NV>0
  if sum(IDV(:,2) == 5) >0;
     bhat=zeros(NV,1); %NVX1 vector to hold optimal b
     bhat(IDV(:,2) ~= 5,1)=paramhat(NF+1:NF+sum(IDV(:,2) ~= 5),1);  %Error comp b equals 0
     what=paramhat(NF+sum(IDV(:,2) ~= 5)+1:end,1); %NVX1 vector of optimal w
  else
     bhat=paramhat(NF+1:NF+NV,1);
     what=paramhat(NF+NV+1:end,1);
  end;
end

if sum(eig(ihess)<0)>0
    disp('The Hessian is not positive definite');
    disp('Using the outer product of the scores to generate standard errors');
    [scoreop]=covscore(fhat,bhat,what);
    hessian=scoreop;
    ihess=inv(scoreop);
end
stderr=sqrt(diag(ihess));

%Segment parameters and account for unestimated zero mean in distribution 5
if NF>0
  fsd=stderr(1:NF,1);       %NVX1 vector of fixed coeff standard errors
end

if NV>0
  if sum(IDV(:,2) == 5) >0;
     bsd=zeros(NV,1);  %NVX1 vector to hold optimal b ses
     bsd(IDV(:,2) ~= 5,1)=stderr(NF+1:NF+sum(IDV(:,2) ~= 5),1);     %Same for se
     wsd=stderr(NF+sum(IDV(:,2) ~= 5)+1:end,1); %NVX1 vector of optimal w ses
  else
     bsd=stderr(NF+1:NF+NV,1);
     wsd=stderr(NF+NV+1:end,1);
  end;
end

if NV>0
    [VCvec, VCSEvec]=randomcoefVCOVSE(what,ihess);
end

disp('RESULTS');
disp(' ');
disp(' ')
if NF>0
disp('FIXED COEFFICIENTS');
disp(' ');
disp('                      F      ');
disp('              ------------------ ');
disp('                Est         SE ');
for r=1:length(NAMESF);
    fprintf('%-10s %10.4f %10.4f\n', NAMESF{r,1}, [fhat(r,1) fsd(r,1)]);
end
disp(' ');
end

 if NV>0;
 disp('RANDOM COEFFICIENTS - "MEANS"');

 disp(' ');
 disp('                      B       ');
 disp('              ------------------ ');
 disp('                 Est     SE    ');
 for r=1:length(NAMES);
     fprintf('%-10s %10.4f %10.4f\n', NAMES{r,1}, [bhat(r,1) bsd(r,1)]);
 end

 disp('RANDOM COEFFICIENTS - "COVARIANCE"');

 disp(' ');
 disp('                                      W');
 disp('                            -----------------------');
 disp('                                Est         SE');
 x=0;
 if corrc==1
  for i=1:NV
    for j=1:i
       fprintf('%-10s %-10s %10.4f %10.4f\n',NAMES{i,1}, NAMES{j,1}, [VCvec(x+1,1) VCSEvec(x+1,1)]);
       x=x+1;
    end
  end
 elseif corrc==0
  for i=1:NV
     fprintf('%-10s %-10s %10.4f %10.4f\n',NAMES{i,1}, NAMES{i,1}, [VCvec(i,1) VCSEvec(i,1)]);
  end
 end

%Create draws of coefficients from B-hat and W-hat

C=trans(bhat,what,DR,NP);
C=reshape(C,NV,NP*NMEM);

%This section of good uses estimated parameters and random draws to specify
%some features of the 'empricial' distribution.
disp('Distribution of coefficients in population implied by B-hat and W-hat.');
disp('using last NMEM draws.');
disp(' ');
jj={'normal';'lognormal';'truncnormal';'S_B';'normal0mn';'triangular'};
disp('                            Mean      StdDev     Share<0    Share=0');
kk=[mean(C,2) std(C,0,2) mean((C < 0),2) mean((C == 0),2)];
for r=1:length(NAMES);
    mm=IDV(r,2);
    fprintf('%-10s %-11s %10.4f %10.4f %10.4f %10.4f\n', NAMES{r,1}, jj{mm,1},kk(r,:));
end
if corrc==1
 disp('                            Covariance');
 CV=cov(C');
 for i=1:NV
   for j=1:i
      fprintf('%-10s %-10s %10.4f\n',NAMES{i,1}, NAMES{j,1}, CV(i,j));
   end
 end
 disp(' ');
 end
end
disp(' ');
disp('ESTIMATED PARAMETERS AND FULL COVARIANCE MATRIX.');
disp('The estimated values of the parameters are:');
disp(paramhat);
disp('The covariance matrix for these parameters is:');
disp(ihess);

disp(' ');
disp('You can access the estimated parameters as variable paramhat,');
disp('the gradient of the negative of the log-likelihood function as variable grad,');
disp('the hessian of the negative of the log-likelihood function as variable hessian,');
disp('and the inverse of the hessian as variable ihess.');
disp('The hessian is calculated by the BFGS updating procedure.');

ll=-fval;

if NV==0
    bhat=[];
    what=[];
    bsd=[];
    wsd=[];
end
save(CoefFile,'fhat','bhat','what','fsd','bsd','wsd','NCSMAX','DR','MDR','ll','ihess');
save(BootFile,'paramhat','hessian')

diary off
