function equilibrium(ParameterFileReg,ParameterFileEst,aggregate,AllDataFile)

global NV NF NCS
global IDV IDF
global NDRAWS NMEM NTAKES NP NCSMAX 
global WANTWGT WGT
global DR MDR

global S PV PVI CC1 CC2 corrc
global dsm dcs alt mar asymmetry OProd OFirm

eval(ParameterFileReg);
eval(ParameterFileEst);

load(AllDataFile);
% If price random coefficient is log normal, negate variables involving
% price
if isempty(IDV)==0
 if sum(IDV(1,:)==PV)>0
    if IDV(find(IDV(1,:)==PV),2)==2
        XMAT(:,PV)= -XMAT(:,PV);
        if isempty(PVI)==0
            XMAT(:,PVI(:,1)')= -XMAT(:,PVI(:,1)');
        end
    end
 end
end

%Obtain market level price
%This is done by computing the average product price in a market. Often
%market is defined so that product price is constant within a market
MarkC=XMAT(:,mar);  %Market data column
Options=XMAT(:,alt);  %Column of options
nMarket=max(MarkC);  %Number of markets
Price=zeros(TALT,nMarket);   %Matrix to hold price
if pricedata==0
    for m=1:nMarket
        Mindex=S; 
        Mindex(Market~=m)=0;   %TALTxNCSMAXxNP matrix of market relevant obs
        Moobs=sum(sum(Mindex,2),3); %TALTx1 total obs per option in market
        for i=1:TALT
            if max(max(Mindex(i,:,:)))>0 %If option is present in market
                Price(i,m)=sum(XMAT(MarkC==m & Options==i,PV))/Moobs(i);
            end
        end
    end
    clear Mindex MTALT Moobs
elseif pricedata==1
    Price=load(PriceDataFile);
    Price=Price(:,2:nMarket+1);
end

NEWPRICE=zeros(size(XMAT,1),1);
for i=1:TALT
   for m=1:nMarket
       NEWPRICE(Options==i & MarkC==m)=Price(i,m);
   end
end
clear ops mark

%Reverse sign of price if price random coefficient is log normal
if isempty(IDV)==0 
 if sum(IDV(1,:)==PV)>0 && pricedata==0
    if IDV(find(IDV(1,:)==PV),2)==2
        Price=-Price;
    end    
 elseif sum(IDV(1,:)==PV)>0 && pricedata==1
    if IDV(find(IDV(1,:)==PV),2)==2
        NEWPRICE=-NEWPRICE;
    end
 end
end

%Update XMAT data to include average prices
[XMAT]=updatedata(XMAT,NEWPRICE,PV,PVI);
%Construct data matrices 
[X, XF]=simulationdata(NP,NCSMAX,XMAT,TALT);

%Compute market shares at disaggregate level
[p, pp]=marketshare(AllCoefFile,X,XF,NP,NCSMAX,TALT,DR,MDR,R,Group,S); 

%Compute market shares at market level
[aggshare]=aggregatemarketshare(p,TALT,Market,nMarket,WGT);

%Compute gradient of utility wrt price
[Gradv]=indexgrad(XMAT,AllCoefFile,NP,NCSMAX,TALT,DR,MDR,PV,PVI,R,Group);

%Reverse sign of utility gradient if random coefficient is log normal
if isempty(IDV)==0
 if sum(IDV(1,:)==PV)>0
    if IDV(find(IDV(1,:)==PV),2)==2
        Gradv=-Gradv;
    end
 end
end 

%Compute price elasticities
%  Set elas = 0 for derivatives
%  Set elas = 1 for elasticities
%  Set elas = 2 for semi-elasticities
elas=1;
[PGradS,GradM]=sharederiv(Gradv,pp,Market,TALT);
[melas]=marketelas(p,PGradS,GradM,TALT,Price,Market,nMarket,MElasOut,WGT,elas);

if sum(IDV(1,:)==PV)>0 && IDV(find(IDV(1,:)==PV),2)==2 
    var=-XMAT(:,PV);
else     
    var=XMAT(:,PV);
end

[delas]=diselas(PGradS,p,var,XMAT,TALT,elas,DElasOut,S,aggregate);

%Load ownership martix
OM=load(FirmDataFile);
ProdCode=OM(:,1);
BrandCode=OM(:,2);
FirmCode=OM(:,3);
clear OM

nFirms=max(FirmCode);
AllFirmsProducts=cell(nFirms,1);
AllCompetitorProducts=cell(nFirms,1);
AllFirmsBrands=cell(nFirms,1);
for f=1:nFirms
    AllFirmsProducts{f}=ProdCode(FirmCode==f);
    AllCompetitorProducts{f}=ProdCode(FirmCode~=f);
    AllFirmsBrands{f}=BrandCode(FirmCode==f);
end
 
[costs]=marginalcosts(Gradv,p,pp,TALT,Price,Market,nMarket,nFirms,AllFirmsProducts,WGT);

testSOC=1;
if testSOC==1
    checkSOC(ParameterFileReg,ParameterFileEst,AllCoefFile,NTAKES,DR,MDR, ...
    TALT,NCSMAX,Price,AllFirmsProducts,nFirms,costs,XMAT,WGT,NP,NCS)
    disp('SOCs satisfied')
end

nBrand=max(BrandCode);
AllOwnBrandProducts=cell(nBrand,1);
for b=1:nBrand
    AllOwnBrandProducts{b}=ProdCode(BrandCode==b);
end

if PriceSim==0
      
   Simvar=zeros(TALT,nMarket);   %Matrix to hold var (at product level)
   for m=1:nMarket
       Mindex=S; 
       Mindex(Market~=m)=0;   %TALTxNCSMAXxNP matrix of market relevant obs
       Moobs=sum(sum(Mindex,2),3); %TALTx1 total obs per option in market
       for i=1:TALT
           if max(max(Mindex(i,:,:)))>0 %If option is present in market
               Simvar(i,m)=sum(XMAT(MarkC==m & Options==i,SV))/Moobs(i);
           end
       end
   end
   
    clear Mindex MTALT Moobs

   AE=load(AdEffectData);
   
   check=sum(AE(:,1)~=XMAT(:,dcs))+sum(AE(:,2)~=XMAT(:,dsm));
   if check>0
       keyboard
   end
   clear check
   
   Brd=AE(:,5);
   OScf=AE(:,7);
    
   finitead_dis(BrandCode,OBrand,Brd,TALT,Market,nMarket,XMAT,OScf,SV,SVI, ...
       SV2,SVI2,AllCoefFile,R,Group,AdFiniteOut,Price);
elseif PriceSim==1
    Simvar=[];
end

Option=repmat(ProdCode,nMarket,1);
Brand=repmat(BrandCode,nMarket,1);
Mark=kron((1:nMarket)',ones(TALT,1));

if PriceSim==0
    ProductData=[Mark Option Brand reshape(aggshare,[TALT*nMarket 1]) ...
        reshape(Price,[TALT*nMarket 1]) reshape(costs,[TALT*nMarket 1]) ...
        reshape(Simvar,[TALT*nMarket 1])];
    save(ProductOut,'ProductData','-ascii','-double','-tabs');
    
elseif PriceSim==1
    ProductData=[Mark Option Brand reshape(aggshare,[TALT*nMarket 1]) ...
        reshape(Price,[TALT*nMarket 1]) reshape(costs,[TALT*nMarket 1])];
    save(ProductOut,'ProductData','-ascii','-double','-tabs');
end

if aggregate==1 && R>1
    DisData=[XMAT(:,size(XMAT,2)) XMAT(:,mar) XMAT(:,alt) ...
        kron(WGT',ones(TALT,1)) reshape(squeeze(p),[TALT*NP 1])];
    save(DisOut,'DisData','-ascii','-double','-tabs');
elseif aggregate==0
    po=reshape(p,[TALT*NCSMAX*NP 1]);
    So=reshape(S,[TALT*NCSMAX*NP 1]);
    DisData=[XMAT(:,dsm) XMAT(:,dcs) XMAT(:,size(XMAT,2)) XMAT(:,mar) XMAT(:,alt) ...
        po(So==1)];
    save(DisOut,'DisData','-ascii','-double','-tabs');   
end    

save(EqFile,'nMarket','Price','Simvar','costs','aggshare');