% Input param is a column vector of parameters, dimension (NF+NV+NV)x1
%     containing the fixed coefficients, the first parameters of the random
%     coefficients, and then the second parameters of the random coefficients
% Output ll is the scalar value of the negative of the simulated log-likelihood 
%     at the input parameters

function [ll, g] =loglik(param)

global NV NF IDV WANTWGT WGT corrc
%Define vector of fixed coeffs f, param1 of random coeffs b, and param2 of
%random coeffs W
%Notice b includes error comp vars coefficient, set to 0

small=1e-321;

if NF>0
  f=param(1:NF,1);  %Fixed parameters
else
  f=[];
end

if NV>0
  if sum(IDV(:,2) == 5) >0; %If any variables have only error components
     b=zeros(NV,1);         %Vector to hold param1 of random coeffs
     b(IDV(:,2) ~= 5,1)=param(NF+1:NF+sum(IDV(:,2) ~= 5),1);    %Element for error comp var set to 0
     w=param(NF+sum(IDV(:,2) ~= 5)+1:end,1); %Vector to hold param1 of random coeffs
  else
     b=param(NF+1:NF+NV,1);
%     w=param(NF+NV+1:NF+NV+NV,1);
     w=param(NF+NV+1:end,1);
  end;
else
  b=[];
  w=[];
end
% Compute contribution to likelihood and gradient for all households
[p g]=llgrad2(f,b,w); 

%%
if sum(isnan(p))>0 || sum(p==inf)>0
    keyboard
end

if sum(sum(isnan(g)))>0 || sum(sum(g==inf))>0
    keyboard
end
%%
if WANTWGT == 0||WANTWGT == 2
    ll=-sum(log(p+small),2);  %Negative of likelihood
    g=-sum(g,2);        %(NV+NV+NF)x1 gradient of negative of likelihood
else
    ll=-sum(WGT.*log(p+small),2);
    g=-sum(repmat(WGT,size(g,1),1).*g,2);
end

if NV>0 & sum(IDV(:,2)==5) >0 ;  %Zero mean error components
   if corrc==1
    z=[ones(NF,1) ; IDV(:,2) ~= 5 ; ones(0.5*NV*(NV+1),1)];
   elseif corrc==0
    z=[ones(NF,1) ; IDV(:,2) ~= 5 ; ones(NV,1)];
   end
   g=g(z==1,1); %Remove gradient for mean of error component variable
end


