cap log close
clear
set more off

global Path "C:/DuboisGriffithOConnell.2017.ReStud"
global P    "$Path\Stata_files\Estimation"
global PA   "$Path\Stata_files\Advertising"

**************************************************************************
**A) Routines to define products
**************************************************************************

cap prog drop branddef
prog def branddef
   gen     agg_manu = 1 if regexm(brand,"Pringles")>0
   replace agg_manu = 2 if manu=="Walkers Snack Foods Ltd"
   replace agg_manu = 3 if manu=="United Biscuits (UK)Ltd"|manu=="KP Snacks"
   replace agg_manu = 4 if manu=="Tayto Group Ltd"
   replace agg_manu = 5 if manu=="Asda Stores Ltd"
   replace agg_manu = 6 if manu=="Tesco Food Stores Ltd"
   replace agg_manu = 7 if agg_manu==. & inside==1

   lab def agg_manu 1 "Procter & Gamble" 2 "Walkers" 3 "United Biscuits" 4 "Tayto" 5 "Asda" 6 "Tesco" 7 "Other"
   lab val agg_manu agg_manu

   gen     agg_brand = 1  if agg_manu == 1
   replace agg_brand = 2  if manu=="Walkers Snack Foods Ltd" & brand=="Walkers Regular Crisps"
   replace agg_brand = 3  if manu=="Walkers Snack Foods Ltd" & (brand=="Walkers Snstns Assrtmnt" | brand=="Walkers Snstns Corn Sncks" | brand=="Walkers Snstns Crackers" | brand=="Walkers Snstns Crisps" | brand=="Walkers Snstns Indnsn Crk" | brand=="Walkers Snstns Olive Oil" | brand=="Walkers Snstns Orntl Crkr" | brand=="Walkers Snstns Ppdm Bites")
   replace agg_brand = 4  if manu=="Walkers Snack Foods Ltd" & (brand=="Walkers Doritos"|brand=="Walkers Doritos 3Ds"|brand=="Walkers Doritos Dippas"|brand=="Walkers Doritos ID3"|brand=="Walkers Doritos Collision"|brand=="Walkers Doritos Latinos")
   replace agg_brand = 5  if manu=="Walkers Snack Foods Ltd" & agg_brand==.
   replace agg_brand = 6  if agg_manu==3
   replace agg_brand = 7  if agg_manu==4
   replace agg_brand = 8 if agg_manu==5
   replace agg_brand = 9 if agg_manu==6
   replace agg_brand = 10 if agg_manu==7 & agg_brand==.

   lab def agg_brand 1 "Pringles" 2 "Walkers Reg" 3 "Walkers Sens" 4 "Walkers Dor" 5 "Walkers Oth" 6 "KP" 7 "GW" 8 "Asda" 9 "Tesco" 10 "Other"
   lab val agg_brand agg_brand
end

cap prog drop prodindef
prog def prodindef
   gen     xsize=1 if volume<=0.150
   replace xsize=2 if volume>0.150&volume<=0.3
   replace xsize=3 if volume>0.3&volume~=.
   lab def xsize 1 "<150g" 2 "150-300g" 3 "300g+"
   lab val xsize xsize

   ** Pringles
   drop if agg_brand==1 & xsize==1
   gen     product = 1 if agg_brand==1 & xsize==2
   replace product = 2 if agg_brand==1 & (xsize==3)

   ** Walkers Regular
   drop if agg_brand==2 & xsize==1
   replace product = 3 if agg_brand==2  & xsize==2
   replace product = 4 if agg_brand==2  & xsize==3

   ** Walkers Sensations

   drop if agg_brand==3 & xsize==1
   replace product = 5 if agg_brand==3  & xsize==2
   replace product = 6 if agg_brand==3  & xsize==3

   ** Walkers Doritos
   drop if agg_brand==4 & xsize==1
   replace product = 7 if agg_brand==4 & xsize==2
   replace product = 8 if agg_brand==4 & xsize==3

   ** Walkers Others
   replace product = 9  if agg_brand==5 & xsize==1
   replace product = 10 if agg_brand==5 & xsize==2
   replace product = 11 if agg_brand==5 & xsize==3

   ** KP
   replace product = 12 if agg_brand==6 & xsize==1
   replace product = 13 if agg_brand==6 & xsize==2
   replace product = 14 if agg_brand==6 & xsize==3

   ** Golden Wonder
   replace product = 15 if agg_brand==7 & xsize==1
   replace product = 16 if agg_brand==7 & xsize==2
   replace product = 17 if agg_brand==7 & xsize==3

   ** Asda
   replace product = 18 if agg_brand==8 & xsize==1
   replace product = 19 if agg_brand==8 & xsize==2
   replace product = 20 if agg_brand==8 & xsize==3

   ** Tesco
   replace product = 21 if agg_brand==9 & xsize==1
   replace product = 22 if agg_brand==9 & xsize==2
   replace product = 23 if agg_brand==9 & xsize==3

   ** Other
   replace product = 24 if agg_brand==10 & xsize==1
   replace product = 25 if agg_brand==10 & xsize==2
   replace product = 26 if agg_brand==10 & xsize==3

   cap lab def prod_in 1 "Pringles:150-300g"  2  "Pringles:300g+" 3  "Walkers Reg:150-300g"  4  "Walkers Reg:300g+"  5  "Walkers Sens:150-300g"  6  "Walkers Sens:300g+"  7 "Walkers Dor:150-300g"  8 "Walkers Dor:300g+" 9 "Walkers Oth:<150g"  10 "Walkers Oth:150-300g"  11 "Walkers Oth:300g+" 12 "KP:<150g"  13 "KP:150-300g"  14 "KP:300g+" 15 "GW:<150g"  16 "GW:150-300g"  17 "GW:300g+" 18 "Asda:<150g"  19 "Asda:150-300g"  20 "Asda:300g+" 21 "Tesco:<150g"  22 "Tesco:150-300g"  23 "Tesco:300g+" 24 "Other:<150g"  25 "Other:150-300g"  26 "Other:300g+"
   lab val product prod_in

end

cap prog drop prodoutdef
prog def prodoutdef
    gen     product = 101 if agg_brand==2 & volume<0.046
    replace product = 102 if agg_brand==2 & volume>=0.046

    replace product = 103 if agg_brand==3
    replace product = 104 if agg_brand==4

    replace product = 105 if agg_brand==5 & volume<0.03
    replace product = 106 if agg_brand==5 & volume>=0.03

    replace product = 107 if agg_brand==6

    replace product = 108 if agg_brand==7 & volume<0.04
    replace product = 109 if agg_brand==7 & volume>=0.04

    replace product = 110 if agg_brand==10 & volume<0.04
    replace product = 111 if agg_brand==10 & volume>=0.04

    replace product = 999 if agg_brand==999

    cap lab def prod_out 101 "Walkers Reg 34.5g:FOTG" 102 "Walkers Reg 50g:FOTG" 103 "Walkers Sens:FOTG" 104 "Walkers Dor:FOTG" 105 "Walkers Oth <30g:FOTG" 106 "Walkers Oth 30g+:FOTG" 107 "KP:FOTG" 108 "GW <40g:FOTG" 109 "GW 40g+:FOTG" 110 "Other <40g:FOTG" 111 "Other 40g+:FOTG" 999 "Outside"
    lab val product prod_out
end


cap prog drop health
prog def health

    gen     energy_score = 0  if energy_kj<=335
    replace energy_score = 1  if energy_kj>335  &energy_kj<=670
    replace energy_score = 2  if energy_kj>670  &energy_kj<=1005
    replace energy_score = 3  if energy_kj>1005 &energy_kj<=1340
    replace energy_score = 4  if energy_kj>1340 &energy_kj<=1675
    replace energy_score = 5  if energy_kj>1675 &energy_kj<=2010
    replace energy_score = 6  if energy_kj>2010 &energy_kj<=2345
    replace energy_score = 7  if energy_kj>2345 &energy_kj<=2680
    replace energy_score = 8  if energy_kj>2680 &energy_kj<=3015
    replace energy_score = 9  if energy_kj>3015 &energy_kj<=3350
    replace energy_score = 10 if energy_kj>3350 &energy_kj!=.

    gen     sat_score = 0  if saturates<=1
    replace sat_score = 1  if saturates>1  &saturates<=2
    replace sat_score = 2  if saturates>2  &saturates<=3
    replace sat_score = 3  if saturates>3  &saturates<=4
    replace sat_score = 4  if saturates>4  &saturates<=5
    replace sat_score = 5  if saturates>5  &saturates<=6
    replace sat_score = 6  if saturates>6  &saturates<=7
    replace sat_score = 7  if saturates>7  &saturates<=8
    replace sat_score = 8  if saturates>8  &saturates<=9
    replace sat_score = 9  if saturates>9  &saturates<=10
    replace sat_score = 10 if saturates>10 &saturates!=.

    gen     sug_score = 0  if sugars<=4.5
    replace sug_score = 1  if sugars>4.5  &sugars<=9
    replace sug_score = 2  if sugars>9    &sugars<=13.5
    replace sug_score = 3  if sugars>13.5 &sugars<=18
    replace sug_score = 4  if sugars>18   &sugars<=22.5
    replace sug_score = 5  if sugars>22.5 &sugars<=27
    replace sug_score = 6  if sugars>27   &sugars<=31
    replace sug_score = 7  if sugars>31   &sugars<=36
    replace sug_score = 8  if sugars>36   &sugars<=40
    replace sug_score = 9  if sugars>40   &sugars<=45
    replace sug_score = 10 if sugars>45   &sugars!=.

    gen     sod_score = 0  if sodium<=0.09
    replace sod_score = 1  if sodium>0.09 &sodium<=0.18
    replace sod_score = 2  if sodium>0.18 &sodium<=0.27
    replace sod_score = 3  if sodium>0.27 &sodium<=0.36
    replace sod_score = 4  if sodium>0.36 &sodium<=0.45
    replace sod_score = 5  if sodium>0.45 &sodium<=0.54
    replace sod_score = 6  if sodium>0.54 &sodium<=0.63
    replace sod_score = 7  if sodium>0.63 &sodium<=0.72
    replace sod_score = 8  if sodium>0.72 &sodium<=0.81
    replace sod_score = 9  if sodium>0.81 &sodium<=0.9
    replace sod_score = 10 if sodium>0.9  &sodium!=.

    ***Based on AOAC scale
    gen     fruit_score = 0

    gen     fib_score = 0  if fibre<=0.9
    replace fib_score = 1  if fibre>0.9 &fibre<=1.9
    replace fib_score = 2  if fibre>1.9 &fibre<=2.8
    replace fib_score = 3  if fibre>2.8 &fibre<=3.7
    replace fib_score = 4  if fibre>3.7 &fibre<=4.7
    replace fib_score = 5  if fibre>4.7 &fibre!=.

    gen     prot_score = 0  if protein<=1.6
    replace prot_score = 1  if protein>1.6 &protein<=3.2
    replace prot_score = 2  if protein>3.2 &protein<=4.8
    replace prot_score = 3  if protein>4.8 &protein<=6.4
    replace prot_score = 4  if protein>6.4 &protein<=8.0
    replace prot_score = 5  if protein>8.0 &protein!=.

    gen A_score = energy_score+sat_score+sug_score+sod_score

    gen health_cost = 0
    replace health_cost = A_score - fruit_score - fib_score - prot_score if A_score<11
    replace health_cost = A_score - fruit_score - fib_score - prot_score if A_score>=11 & fruit_score==5
    replace health_cost = A_score - fruit_score - fib_score              if A_score>=11 & fruit_score<5

end

**************************************************************************
**B) Construct advertising data
**************************************************************************

do "$Path/Programs/createaddata.do"

**************************************************************************
**C) Construct product attributes
**************************************************************************

u "M:\TNS\extractedfiles\fotg_data\rf1545_12.dta",clear
keep if totalfotgmarket=="Crisps" | totalfotgmarket=="Savoury Snacks"
keep prodcode productdesc manu holding brand valueprivatelabels
sa "$P\attributes_1545.dta",replace

u "M:\TNS\extractedfiles\product_attributes\2008-2012\rf962_0812.dta",clear
keep prodcode productdesc manu holding brand sizegroup valueprivatelabels size
sa "$P\attributes_962.dta",replace

u "M:\TNS\extractedfiles\product_attributes\2008-2012\rf951_0812.dta",clear
keep prodcode productdesc manu holding brand sizegroup valueprivatelabels size
append using "$P\attributes_962.dta"
gen out = 0
append using "$P\attributes_1545.dta"
replace out = 1 if out==.
bysort prodcode: gen n = _n
bysort prodcode: gen N = _N

egen foodout = min(out),by(prodcode)

tab N if n==1
drop if N==2 & size==""
drop n N

gen pd_temp = lower(word(productdesc,-1))
gen pack = .
forval x=8(-1)3 {
   replace pack = real(substr(pd_temp,-`x',`x'-2)) if pack==. & strpos(pd_temp,"-")==0&real(substr(pd_temp,-2,1))==.
}
forval x=8(-1)2 {
   replace pack = real(substr(pd_temp,-`x',`x'-1)) if pack==. & strpos(pd_temp,"-")==0&real(substr(pd_temp,-2,1))!=.
}
forval x=6(-1)3 {
   replace pack = real(substr(pd_temp,-`x',`x'-1)) if pack==. & strpos(pd_temp,"-")==0&real(substr(pd_temp,-2,1))==.
}
forval x=8(-1)3 {
   replace pack = real(substr(pd_temp,-`x',`x'-1)) if pack==. & strpos(pd_temp,"-")==0&real(substr(pd_temp,-2,1))==.
}
forval x=8(-1)2 {
   replace pack = real(substr(pd_temp,-`x',`x'-1)) if pack==. & strpos(pd_temp,"-")==0&real(substr(pd_temp,-2,1))==.
}
replace pack = 2*pack if prodcode==99442

gen multi = regexm(lower(productdesc)," pack")

forval n=2/70{
    qui replace multi = 1 if regexm(lower(productdesc),"`n'x")
    qui replace multi = 1 if regexm(lower(productdesc),"`n'p")
}

gen drop = multi==1 & foodout==1

drop out foodout

sa "$P\attributes.dta",replace

**************************************************************************
**D) Construct household attributes
**************************************************************************

u "M:\TNS\extractedfiles\panel_data\hhpanel_all.dta",clear

rename msage age
rename mssex sex

gen nkids0_9=0
gen nkids10_13=0
gen nkids14_17=0
gen n1864=0
gen n65plus=0
foreach n of numlist 1(1)12 {
   replace nkids0_9=nkids0_9+1 if ageper`n'<=9
   replace nkids10_13=nkids10_13+1 if ageper`n'>=10&ageper`n'<=13
   replace nkids14_17=nkids14_17+1 if ageper`n'>=14&ageper`n'<=17
   replace n1864=n1864+1 if ageper`n'>=18&ageper`n'<65
   replace n65plus=n65plus+1 if ageper`n'>=65 & ageper`n'!=.
}

drop if ageper1<18  | ageper1==.
gen nkids=nkids0_9+nkids10_13+nkids14_17
gen nads=n1864+n65plus

gen     fz=1 if n1864==1 & n65plus==0 & nkids==0
replace fz=2 if n1864==0 & n65plus==1 & nkids==0
replace fz=3 if nads==2 & nkids==0
replace fz=4 if nads==2 & n65plus>0 & nkids==0
replace fz=5 if nads>2 & nkids==0

replace fz=6 if nads==1 & nkids>0
replace fz=7 if nads>=2 & nkids>0 & nkids0_9>0
replace fz=8 if nads>=2 & nkids>0 & nkids0_9==0

lab def fz 1 "Single young" 2 "Single pensioner" 3 "Couple no child" 4 "Couple pensioner" 5 "Multi adult" 6 "Single parent" 7 "Young child (0-9)" 8 "Old child (10+)"
lab val fz fz
tab famtype fz
tab fz,miss

**No kids no pensioners
gen     hhtype = 1 if fz==1|fz==3|fz==5
**Pensioners
replace hhtype = 2 if fz==2|fz==4
**Households with kids
replace hhtype = 3 if fz==6|fz==7|fz==8

cap lab def hhtype 1 "No kids" 2 "Pensioners" 3 "Kids"
lab val hhtype hhtype

**If household income is missing, replace it with household's average
**household income in reported years
replace hhinc = . if hhinc==0
egen mean_hhinc = mean(hhinc),by(hhno)
replace hhinc = int(mean_hhinc+0.5) if hhinc==.
drop mean_hhinc

drop if demyear<2009
drop if class==.|hhinc==.

rename demyear year

gen indvno=0

keep  hhno indvno year hhinc class fz hhtype age sex hhsize
order hhno indvno year hhinc class fz hhtype age sex hhsize

sa "$P/hh_panel.dta",replace

u "M:\TNS\extractedfiles\fotg_data\panel_200910.dta",clear
append using "M:\TNS\extractedfiles\fotg_data\panel_201112.dta"

rename gender sex
rename demyear year

keep hhno indvno year age sex

gen out = 1
append using "$P/hh_panel.dta"
replace out = 0 if out==.

**Keep households/individuals present on both WP and FOTG data
egen temp = max(out),by(hhno)
drop if temp==0
drop temp

egen temp = min(out),by(hhno)
drop if temp==1
drop temp

foreach v in hhinc class fz hhtype hhsize {
    egen temp = min(`v'),by(hhno year)
    replace `v' = temp if `v'==.
    drop temp
}

drop if hhinc==.

bysort hhno indvno year: gen N = _N
drop if out==1 & N==2
drop out N

so hhno indvno year
sa "$P/ind_attributes.dta",replace

keep if indvno==0
drop indvno
sa "$P/hh_attributes.dta",replace

u "$P/hh_attributes.dta",clear

gen     hhinc_m =  5000 if hhincome==1
replace hhinc_m = 15000 if hhincome==2
replace hhinc_m = 25000 if hhincome==3
replace hhinc_m = 35000 if hhincome==4
replace hhinc_m = 45000 if hhincome==5
replace hhinc_m = 55000 if hhincome==6
replace hhinc_m = 65000 if hhincome==7
replace hhinc_m = 75000 if hhincome==8

gen hhinc_pp = hhinc_m/hhsize

gen     class1 = 1 if class==1|class==2
replace class1 = 2 if class==3|class==4|class==5

centile hhinc_pp if hhtype==1,centile(33.333 66.667)

gen     group = 1  if hhtype==1 & hhinc_pp>r(c_2)                    & class1==1
replace group = 2  if hhtype==1 & hhinc_pp<=r(c_2) & hhinc_pp>r(c_1) & class1==1
replace group = 3  if hhtype==1 & hhinc_pp<=r(c_1)                   & class1==1

replace group = 4  if hhtype==1 & hhinc_pp>r(c_1)                    & class1==2
replace group = 5  if hhtype==1 & hhinc_pp<=r(c_1)                   & class1==2

replace group = 6  if hhtype==2

centile hhinc_pp if hhtype==3,centile(33.333 66.667)

replace group = 7  if hhtype==3 & hhinc_pp>r(c_2)                    & class1==1
replace group = 8  if hhtype==3 & hhinc_pp<=r(c_2) & hhinc_pp>r(c_1) & class1==1
replace group = 9  if hhtype==3 & hhinc_pp<=r(c_1)                   & class1==1

replace group = 10 if hhtype==3 & hhinc_pp>r(c_1)                    & class1==2
replace group = 11 if hhtype==3 & hhinc_pp<=r(c_1)                   & class1==2

cap lab def group 1  "No kids, high inc, high cl" 2  "No kids, med inc, high cl" 3  "No kids, low inc, high cl" 4  "No kids, high_med inc, low cl" 5  "No kids, low inc, low cl" 6  "Pensioners" 7  "Kids, high inc, high cl" 8  "Kids, med inc, high cl" 9  "Kids, low inc, high cl" 10 "Kids, high_med inc, low cl" 11 "Kids, low inc, low cl"
lab val group group

keep hhno year group
sa "$P/hh_grouping.dta",replace

***************************************************************************
**E) Starting set of households
**************************************************************************

u "M:\TNS\extractedfiles\fotg_data\purchase_200910.dta",clear
append using "M:\TNS\extractedfiles\fotg_data\purchase_201112.dta"

bysort hhno year: keep if _n==1
keep hhno year

sa "$P/HHfotg.dta",replace

use "M:\TNS\extractedfiles\index_files\hh_dailyshop_expenditure_12.dta",clear

gen year = int(date/10000)

keep hhno year

bysort hhno year: keep if _n==1

**Keep only hh where hh is active in both data sets
merge 1:1 hhno year using "$P/HHfotg.dta"
keep if _m==3
drop _m

merge m:1 hhno year using "$P/hh_attributes.dta"
keep if _m==3
drop _m

merge m:1 hhno using "$PA/hh_media_tv.dta"
keep if _m==3
drop _m

keep hhno year

sa "$P/HHs.dta",replace

*************************************************************************
**F) Obtain nutrient information
**************************************************************************

u "M:\TNS\extractedfiles\product_attributes\2008-2012\rf15_0812.dta",clear

keep prodcode brand

sa "$P/rf_15_brands.dta",replace


u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2009.dta",clear
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2010.dta"

merge m:1 prodcode using "$P/rf_15_brands.dta"
keep if _m==3
drop _m

keep if brand=="McVities Mini Chdrs"|brand=="McVities Mini Chdrs Crnkl"
drop brand

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_951_2010.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_962_2010.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_951_2009.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_962_2009.dta"

gen year = int(date/10000)
gen month = int(date/100) - int(date/10000)*100
drop if year==2009 & month<6
drop if year==2010 & month>10

foreach v in energy_kj energy_kcal protein carbohydrate sugars fat saturates fibre sodium {
    replace `v'=`v'/100
}

foreach v in energy_kj energy_kcal protein carbohydrate sugars fat saturates fibre sodium {

    bysort prodcode:     gen N  = _n
    bysort prodcode `v': gen N_`v' = _n
    gen ratio_`v' = N_`v'/N
    egen max_`v' = max(ratio_`v'),by(prodcode)
    gen temp_`v' = `v' if ratio_`v'==max_`v'
    egen `v'_mode = min(temp_`v'),by(prodcode)
    drop `v' N N_`v' ratio_`v' max_`v' temp_`v'
    rename `v'_mode `v'
}

gen purchase = 1

collapse (sum) purchase (mean) energy_kj energy_kcal protein carbohydrate sugars fat saturates fibre sodium,by(prodcode)

sa "$P/prodcode_nutrient.dta",replace

merge m:1 prodcode using "$P\attributes.dta"
keep if _m==3
drop _m drop

gen inside=1
branddef

replace saturates = 10 if agg_brand==1 & saturates==0

egen purchase2 = sum(purchase),by(agg_brand)

foreach v in energy_kj energy_kcal protein carbohydrate sugars fat saturates fibre sodium {
    replace `v'=`v'*(purchase/purchase2)
}

collapse (sum) energy_kj energy_kcal protein carbohydrate sugars fat saturates fibre sodium,by(agg_brand)

sa "$P/FoodIn_brand_nutrients.dta",replace

u "M:\TNS\extractedfiles\fotg_data\purchase_200910.dta",clear
append using "M:\TNS\extractedfiles\fotg_data\purchase_201112.dta"

egen temp = group(year month)
drop if temp>17
drop temp

format date %td
keep  hhno indvno date month year week demyear prodcode npacks expenditure volume
order hhno indvno date month year week demyear prodcode npacks expenditure volume
drop if exp==0|vol==0

gen day=day(date)
drop date
gen long date=year*10000+month*100+day
drop month year

merge m:1 prodcode using "M:\TNS\extractedfiles\fotg_data\rf1545_12.dta"
keep if _m==3
drop _m

gen inside = totalfotgmarket=="Crisps" | totalfotgmarket=="Savoury Snacks"
keep if inside==1
keep prodcode

gen purchase_fotg = 1

collapse (sum) purchase_fotg,by(prodcode)

merge 1:1 prodcode using "$P/prodcode_nutrient.dta"
keep if _m==3
drop _m purchase
rename purchase_fotg purchase

merge m:1 prodcode using "$P\attributes.dta"
keep if _m==3
drop if drop==1
drop _m drop

gen inside=1
branddef
drop if agg_brand==1|agg_brand==8|agg_brand==9
egen purchase2 = sum(purchase),by(agg_brand)

foreach v in energy_kj energy_kcal protein carbohydrate sugars fat saturates fibre sodium {
    replace `v'=`v'*(purchase/purchase2)
}

collapse (sum) energy_kj energy_kcal protein carbohydrate sugars fat saturates fibre sodium,by(agg_brand)

sa "$P/FOTG_brand_nutrients.dta",replace

**************************************************************************
**G) Obtain food on the go purchases
**************************************************************************

u "M:\TNS\extractedfiles\index_files\dates_detail.dta",clear

drop date
gen long date=year*10000+month*100+dayofmonth

drop yearweek demyear dayofweek weekday dayofmonth
drop if year<2009
drop if month<6 & year==2009

egen group = group(week)
sort date
bysort week: gen temp = month if _n==4
egen temp2 = min(temp),by(week)
replace month = temp2
drop temp temp2
bysort week: gen temp = year if _n==4
egen temp2 = min(temp),by(week)
replace year = temp2
drop temp temp2

drop week
rename group week

sa "$P\week.dta",replace

u "M:\TNS\extractedfiles\fotg_data\purchase_200910.dta",clear
append using "M:\TNS\extractedfiles\fotg_data\purchase_201112.dta"

egen temp = group(year month)
drop if temp>17
drop temp

format date %td
keep  hhno indvno date month year week demyear prodcode npacks expenditure volume
order hhno indvno date month year week demyear prodcode npacks expenditure volume
drop if exp==0|vol==0

gen day=day(date)
drop date
gen long date=year*10000+month*100+day
drop month year

drop week
merge m:1 date using "$P\week.dta"
keep if _m==3
drop _m

**Keep only hh-years where hh is active in both data sets
merge m:1 hhno year using "$P/HHs.dta"
keep if _m==3
drop _m

merge m:1 prodcode using "M:\TNS\extractedfiles\fotg_data\rf1545_12.dta"
keep if _m==3
drop _m

gen inside = totalfotgmarket=="Crisps" | totalfotgmarket=="Savoury Snacks"

gen unhealthy = totalfotgmarket=="Cakes & Pastries"|totalfotgmarket=="Chocolate Confectionery"|totalfotgmarket=="Sugar Confectionery"
gen inside2 = inside!=0|unhealthy!=0
egen temp = max(inside2),by(hhno indvno week)
drop if inside2==0 & temp==1

egen temp2 = max(inside),by(hhno indvno week)
drop if inside==0 & temp2==1
drop temp2

bysort hhno indvno week: gen n = _n
drop if temp==0 & n>1
drop n temp

drop if npacks>1 & inside==1

merge m:1 prodcode using "$P\attributes.dta"
drop if _m==2
replace manuf="." if inside==0
replace brand="." if inside==0
drop if drop==1
drop _m drop

replace volume = (pack*npacks)/1000 if inside==1

branddef

replace agg_manu  = 999 if inside==0 & unhealthy==0
replace agg_brand = 999 if inside==0 & unhealthy==0

replace agg_manu  = 199 if inside==0 & unhealthy==1
replace agg_brand = 199 if inside==0 & unhealthy==1

drop if agg_brand==1|agg_brand==8|agg_brand==9

sa "$P/FOTG_brand_transactions.dta",replace

u "$P/FOTG_brand_transactions.dta",clear

prodoutdef

replace product = 199 if unhealthy==1

replace npacks = 0 if agg_brand==999|agg_brand==199
replace volume = 0 if agg_brand==999|agg_brand==199
replace expend = 0 if agg_brand==999|agg_brand==199

collapse (sum) npacks volume exp,by(hhno indvno year month week agg_brand agg_manu product)

**Clean: Drop individual that purchases unrealistically high number of packs
egen temp = sum(npacks),by(hhno indvno week)
gen temp2 = temp>7
egen dodgy = max(temp2),by(hhno indvno)
drop if dodgy==1

**Model purchase of product consumer buys most of in week
sort hhno indvno week volume
by hhno indvno week: gen n=_n
by hhno indvno week: gen N=_N
tab N if n==1
keep if n==N
drop n N

merge m:1 agg_brand using "$P/FOTG_brand_nutrients.dta"
drop if _m==2
drop _m

health
foreach v in health_cost energy_kj saturates sodium {
    replace `v' = 0 if agg_brand==999|agg_brand==199
}
drop energy_kcal protein carbohydrate sugars fat fibre

merge m:1 hhno year using "$P/hh_grouping.dta"
keep if _m==3
drop _m

merge m:1 hhno indvno year using "$P/ind_attributes.dta"
keep if _m==3
drop _m

replace group = 12 if age<18
cap lab def group2 1  "No kids, high inc, high cl" 2  "No kids, med inc, high cl" 3  "No kids, low inc, high cl" 4  "No kids, high_med inc, low cl" 5  "No kids, low inc, low cl" 6  "Pensioners" 7  "Kids, high inc, high cl" 8  "Kids, med inc, high cl" 9  "Kids, low inc, high cl" 10 "Kids, high_med inc, low cl" 11 "Kids, low inc, low cl" 12 "Kid purchase"
lab val group group2

keep  hhno indvno year month week product agg_brand agg_manu product npacks volume expenditure health_cost energy_kj saturates sodium group
order hhno indvno year month week product agg_brand agg_manu product npacks volume expenditure health_cost energy_kj saturates sodium group

bysort hhno indvno: gen ni = _n
bysort hhno indvno: gen Ni = _N

su Ni if ni==1,d

keep if Ni>10
drop ni Ni

sa "$P/FOTG_allweeks_full.dta",replace

**************************************************************************
**H) Obtain food in purchases
**************************************************************************

use "M:\TNS\extractedfiles\index_files\hh_dailyshop_expenditure_12.dta",clear

mer m:1 date using "$P/week.dta"
keep if _m==3
drop _m

keep hhno year month week

bysort hhno year month week: keep if _n==1

**Keep only hh-weeks where hh is active in both data sets
merge m:1 hhno year using "$P/HHs.dta"
keep if _m==3
drop _m

keep hhno week year month

sa "$P/FoodIn_trips.dta",replace

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_534_2009.dta",clear
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_534_2010.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2009.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2010.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_499_2009.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_499_2010.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_1206_2009.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_1206_2010.dta"

gen year = int(date/10000)
gen month = int(date/100) - int(date/10000)*100
drop if year==2009 & month<6
drop if year==2010 & month>10
drop year month

drop if exp==.|vol==.
drop if exp==0|vol==0

mer m:1 date using "$P/week.dta"
keep if _m==3
drop _m

bysort hhno week: keep if _n==1
keep hhno week

sa "$P\FoodIn_unhealthy.dta",replace

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2009.dta",clear
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2010.dta"

merge m:1 prodcode using "$P/rf_15_brands.dta"
keep if _m==3
drop _m

keep if brand=="McVities Mini Chdrs"|brand=="McVities Mini Chdrs Crnkl"
drop brand

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_951_2010.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_962_2010.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_951_2009.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_962_2009.dta"

gen year = int(date/10000)
gen month = int(date/100) - int(date/10000)*100
drop if year==2009 & month<6
drop if year==2010 & month>10
drop year month

drop if exp==.|vol==.
drop if exp==0|vol==0

mer m:1 date using "$P/week.dta"
keep if _m==3
drop _m

**Keep only hh-years where hh is active in both data sets
merge m:1 hhno year using "$P/HHs.dta"
keep if _m==3
drop _m

collapse (sum) expenditure volume npacks,by(hhno year month week prodcode)

merge m:1 prodcode using "$P\attributes.dta"
keep if _m==3
drop _m drop

gen inside=1
branddef

sa "$P/FoodIn_brand_transactions.dta",replace

u "$P/FoodIn_brand_transactions.dta",clear

collapse (sum) npacks volume exp ,by(hhno year month week agg_brand agg_manu)

**Model purchase of product consumer buys most of in week
sort hhno week volume
by hhno week: gen n=_n
by hhno week: gen N=_N
tab N if n==1
keep if n==N
drop n N

**Clean: Drop extremes of volume distribution
drop if volume>1 | volume<=0.05

merge m:1 agg_brand using "$P/FoodIn_brand_nutrients.dta"
drop if _m==2
drop _m

health

drop energy_kcal protein carbohydrate sugars fat fibre

prodindef

**Merge in outside option
merge 1:1 hhno week using "$P/FoodIn_trips.dta"

replace product   = 999 if _m==2
replace agg_brand = 999 if _m==2
replace agg_manu  = 999 if _m==2
drop _m

merge 1:1 hhno week using "$P\FoodIn_unhealthy.dta"
replace product   = 199 if _m==3 & product==999
replace agg_brand = 199 if _m==3 & agg_brand==999
replace agg_manu  = 199 if _m==3 & agg_manu==999
drop if _m==2
drop _m

foreach v in npacks volume expenditure health_cost energy_kj saturates sodium  xsize {
    replace `v' = 0 if agg_brand==999|agg_brand==199
}

merge m:1 hhno year using "$P/hh_grouping.dta"
keep if _m==3
drop _m

keep  hhno year month week product agg_brand agg_manu product npacks volume expenditure health_cost energy_kj saturates sodium group
order hhno year month week product agg_brand agg_manu product npacks volume expenditure health_cost energy_kj saturates sodium group

bysort hhno: gen nh = _n
bysort hhno: gen Nh = _N

su Nh if nh==1,d

keep if Nh>52
drop nh Nh

sa "$P/Foodin_allweeks_full.dta",replace

**************************************************************************
**I) Obtain final samples
**************************************************************************

u "$P/Foodin_allweeks_full.dta",clear

bysort hhno: keep if _n==1

sa "$P/Foodin_hhs.dta",replace

u "$P/FOTG_allweeks_full.dta",clear

egen min = min(week),by(hhno)
egen max = max(week),by(hhno)

bysort hhno: keep if _n==1

merge 1:1 hhno using "$P/Foodin_hhs.dta"
keep if _m==3
drop _m

keep hhno min max

sa "$P/FOTG_active.dta",replace

u "$P/FOTG_allweeks_full.dta",clear

**Keep households in both WP and FOTG
merge m:1 hhno using "$P/FOTG_active.dta"
keep if _m==3
drop _m

bysort hhno indvno: gen n = _n

**Fraction of decision maker's purchase that are outside option
gen i = 1
egen sum_d = sum(i),by(hhno indvno)
gen outside = product==999|product==199
egen sum_n = sum(outside),by(hhno indvno)

gen frac = (sum_n/sum_d)*100
su frac if n==1,d

drop if frac==100
drop frac i sum* outside n

bysort hhno indvno group: gen n = _n
tab group
tab group if n==1
tab product

sa "$P/FOTG_allweeks.dta",replace

**Save separately by group

foreach n of numlist 1(1)12 {

    u "$P/FOTG_allweeks.dta",clear

    keep if group==`n'
    drop group

    keep  hhno indvno year month week agg_brand agg_manu product volume exp
    order hhno indvno year month week agg_brand agg_manu product volume exp

    sort hhno indvno week
    gen index = _n

    sa "$P/FOTG_group`n'.dta",replace

}

u "$P/Foodin_allweeks_full.dta",clear

**Keep households in both WP and FOTG
merge m:1 hhno using "$P/FOTG_active.dta"
keep if _m==3
drop _m

bysort hhno: gen n = _n

**Fraction of decision maker's purchase that are outside option
gen i = 1
egen sum_d = sum(i),by(hhno)
gen outside = product==999|product==199
egen sum_n = sum(outside),by(hhno)

gen frac = (sum_n/sum_d)*100
su frac if n==1,d

drop if frac==100
drop frac i sum* outside n

**Drop food in purchase before or after household is active in FOTG data
drop if week<min
drop if week>max

bysort hhno group: gen n = _n
tab group
tab group if n==1
tab product

sa "$P/FoodIn_allweeks.dta",replace

**Save separately by group

foreach n of numlist 1(1)11 {

    u "$P/Foodin_allweeks.dta",clear

    keep if group==`n'
    drop group

    keep  hhno year month week agg_brand agg_manu product volume expenditure
    order hhno year month week agg_brand agg_manu product volume expenditure

    sort hhno week
    gen index = _n

    sa "$P/Foodin_group`n'.dta",replace

}

*************************************************************************
**J) Create past dependence variables
**************************************************************************

u "$P/HHs.dta",clear

bysort hhno: keep if _n==1
drop year

sa "$P/HHs_temp.dta",replace

u "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2007.dta",clear
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2008.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_15_2009.dta"

merge m:1 prodcode using "$P/rf_15_brands.dta"
keep if _m==3
drop _m

keep if brand=="McVities Mini Chdrs"|brand=="McVities Mini Chdrs Crnkl"
drop brand

append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_951_2009.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_962_2009.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_951_2008.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_962_2008.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_951_2007.dta"
append using "M:\TNS\extractedfiles\purchase_data\Clean_data_by_rfy\CleanRF_962_2007.dta"

gen year = int(date/10000)
gen month = int(date/100) - int(date/10000)*100
drop if year==2009 & month>5
drop year month

drop if exp==.|volume==.
drop if exp==0|volume==0

**Keep only hh-years where hh is active in both data sets
merge m:1 hhno using "$P/HHs_temp.dta"
keep if _m==3
drop _m

collapse (sum) expenditure volume npacks,by(hhno prodcode)

merge m:1 prodcode using "$P\attributes.dta"
keep if _m==3
drop _m drop

gen inside=1
branddef

keep hhno agg_brand
bysort hhno agg_brand: keep if _n==1

sa "$P/FoodIn_priorpurchases.dta",replace

u "$P/Foodin_allweeks.dta",clear

keep hhno year month week agg_brand

egen ind = group(hhno week)

gen chosen = 1
fillin ind agg_brand
drop _fillin
replace chosen=0 if chosen==.

foreach v in hhno year month week {
    egen temp = min(`v'),by(ind)
    replace `v' = temp if `v'==.
    drop temp
}

drop if agg_brand==199|agg_brand==999

sa "$P/Foodin_brandpurchases.dta",replace

u "$P/FOTG_allweeks.dta",clear

keep hhno indvno year month week agg_brand

egen ind = group(hhno ind week)

gen chosen = 1
fillin ind agg_brand
drop _fillin
replace chosen=0 if chosen==.

foreach v in hhno indvno year month week {
    egen temp = min(`v'),by(ind)
    replace `v' = temp if `v'==.
    drop temp
}

drop if agg_brand==199|agg_brand==999

sa "$P/FOTG_brandpurchases.dta",replace

***Experience

u "$P/Foodin_brandpurchases.dta",clear

append using "$P/FOTG_brandpurchases.dta"

collapse (max) chosen,by(hhno week agg_brand)

sort hhno agg_brand week
by hhno agg_brand: gen total = sum(chosen)
by hhno agg_brand: gen diff = total-total[_n-1]

gen pastchoice = total>1 | (total==1&diff==0)

keep hhno week agg_brand pastchoice

merge m:1 hhno agg_brand using "$P/FoodIn_priorpurchases.dta"
drop if _m==2
replace pastchoice = 1 if _m==3
drop _m

sa "$P/Experience.dta",replace

***Habits

u "$P/Foodin_brandpurchases.dta",clear

gen pastmonth = 0
sort hhno agg_brand week
by hhno agg_brand: replace pastmonth = 1 if chosen[_n-1]==1
by hhno agg_brand: replace pastmonth = 1 if chosen[_n-2]==1
by hhno agg_brand: replace pastmonth = 1 if chosen[_n-3]==1
by hhno agg_brand: replace pastmonth = 1 if chosen[_n-4]==1

keep hhno week agg_brand pastmonth

sa "$P/FoodIn_habits.dta",replace

u "$P/FOTG_brandpurchases.dta",clear

gen pastmonth = 0
sort hhno indvno agg_brand week
by hhno indvno agg_brand: replace pastmonth = 1 if chosen[_n-1]==1
by hhno indvno agg_brand: replace pastmonth = 1 if chosen[_n-2]==1
by hhno indvno agg_brand: replace pastmonth = 1 if chosen[_n-3]==1
by hhno indvno agg_brand: replace pastmonth = 1 if chosen[_n-4]==1

keep hhno indvno week agg_brand pastmonth

sa "$P/FOTG_habits.dta",replace

***Connected markets

u "$P/FoodIn_allweeks.dta",clear

drop if agg_brand==199|agg_brand==999

bysort hhno week: keep if _n==1
keep hhno week

sa "$P/FoodIn_crispspurchase.dta",replace

**************************************************************************
**K) Create characteristics for each product
**************************************************************************

u "$P/FOTG_allweeks.dta",clear

foreach v in expenditure volume  {
    replace `v'=`v'/npacks
}

drop if product==999|product==199
gen temp = round(expenditure,0.01)

bysort product week temp: gen N = _N
egen temp2 = max(N),by(product week)

gen price1 = temp   if N==N
gen size1  = volume if N==N

egen price2 = mean(exp),by(product year month)
egen size2  = mean(vol),by(product year month)

collapse (mean) price1 size1 price2 size2 health_cost energy_kj saturates sodium (max) N,by(product week year month)

gen price     = price1
replace price = price2 if N<8
replace price = price2 if product==105|product==106|product==110|product==111

gen size     = size1
replace size = size2 if N<8
replace size = size2 if product==105|product==106|product==110|product==111

fillin product week
tab _f

foreach v in month year  {
    egen temp = min(`v'),by(week)
    replace `v' = temp if `v'==.
    drop temp
}
foreach v in price size {
    egen temp = mean(`v'2),by(product year month)
    replace `v' = temp if `v'==.
    drop temp
}
foreach v in  health_cost energy_kj saturates sodium {
    egen temp = mean(`v'),by(product year month)
    replace `v' = temp if `v'==.
    drop temp
}

keep product week year month price size health_cost energy_kj saturates sodium

sa "$P/FOTG_characteristics.dta",replace

u "$P/Foodin_allweeks.dta",clear

drop if product==999|product==199
gen temp = round(expenditure,0.01)

bysort product week temp: gen N = _N
egen temp2 = max(N),by(product week)

gen price1 = temp   if N==N
gen size1  = volume if N==N

egen price2 = mean(exp),by(product year month)
egen size2  = mean(vol),by(product year month)

collapse (mean) price1 size1 price2 size2 health_cost energy_kj saturates sodium (max) N,by(product week year month)

gen price     = price1
replace price = price2 if N<8
replace price = price2 if product==9|product==10|product==11|product>17

gen size     = size1
replace size = size2 if N<8
replace size = size2 if product==9|product==10|product==11|product>17

fillin product week
tab _f

foreach v in month year  {
    egen temp = min(`v'),by(week)
    replace `v' = temp if `v'==.
    drop temp
}
foreach v in price size {
    egen temp = mean(`v'2),by(product year month)
    replace `v' = temp if `v'==.
    drop temp
}
foreach v in  health_cost energy_kj saturates sodium {
    egen temp = mean(`v'),by(product year month)
    replace `v' = temp if `v'==.
    drop temp
}

keep product week year month price size health_cost energy_kj saturates sodium

sa "$P/FoodIn_characteristics.dta",replace

**************************************************************************
**L) Create data for estimation
**************************************************************************

***Food in

foreach n of numlist 1(1)11{

    u "$P/FoodIn_group`n'.dta",clear

    keep index hhno year month week

    sa "$P/FoodIn_index_vars_group`n'.dta",replace

    u "$P/FoodIn_group`n'.dta",clear

    bysort product: keep if _n==1
    keep product agg_brand agg_manu

    sa "$P/FoodIn_options_vars_group`n'.dta",replace

    u "$P/FoodIn_group`n'.dta",clear

    keep index product
    gen choice = 1
    fillin index product
    drop _fillin
    replace choice=0 if choice==.

    mer m:1 index using "$P/FoodIn_index_vars_group`n'.dta"
    keep if _m==3
    drop _m

    merge m:1 product using "$P/FoodIn_options_vars_group`n'.dta"
    keep if _m==3
    drop _m

    mer m:1 product week using "$P/FoodIn_characteristics.dta"
    drop if _m==2
    drop _m

    foreach v in price size health_cost energy_kj saturates sodium {
        replace `v' = 0 if product==999|product==199
    }

    mer m:1 hhno agg_brand week using "$PA/RGdisagg_ad_stocks.dta",keepusing(os_wads rs_wads)
    rename os_wads own_stock
    rename rs_wads rival_stock
    bysort hhno: egen max=max(_m)
    drop if max==1|max==2
    drop max
    bysort index: egen min=min(_m)
    drop if min==2
    foreach v in own_stock rival_stock {
        replace `v'=0 if agg_brand==199|agg_brand==999
    }
    drop _m min

    merge m:1 hhno week agg_brand using "$P/Experience.dta"
    drop if _m==2
    drop _m
    replace pastchoice = 0 if agg_brand==199|agg_brand==999

    merge m:1 hhno week agg_brand using "$P/FoodIn_habits.dta"
    drop if _m==2
    drop _m
    replace pastmonth = 0 if agg_brand==199|agg_brand==999

    mer m:1 hhno using "$PA:/hh_panel_tv.dta",keepusing(tvreg)
    drop if _m==2
    drop _m

    gen     region = 1 if tvreg==1|tvreg==6|tvreg==10
    replace region = 2 if tvreg==2|tvreg==8|tvreg==9
    replace region = 3 if tvreg==3|tvreg==4|tvreg==5|tvreg==7

    gen pringles = agg_brand==1
    gen walk_reg = agg_brand==2
    gen walk_sen = agg_brand==3
    gen walk_dor = agg_brand==4
    gen walk_oth = agg_brand==5
    gen kp       = agg_brand==6
    gen gw       = agg_brand==7
    gen asda     = agg_brand==8
    gen tesco    = agg_brand==9
    gen other    = agg_brand==10
    gen outside1 = agg_brand==199
    gen outside2 = agg_brand==999

    replace size = size*1000

    label var index              "Index of choice occasion"
    label var hhno               "Index of hh"
    label var year               "Year"
    label var month              "Month"
    label var week               "Week"
    label var agg_brand          "Brand"
    label var agg_manu           "Manufacturer"
    label var product            "Product"
    label var choice             "1 for option chosen"
    label var size               "Option size in Kg"
    label var price              "Option price"
    label var health_cost        "Brand health score"
    label var energy_kj          "KJ per 100g"
    label var saturates          "g per 100g"
    label var sodium             "g per 100g"
    label var pringles           "Brand dummy"
    label var walk_reg           "Brand dummy"
    label var walk_sen           "Brand dummy"
    label var walk_dor           "Brand dummy"
    label var walk_oth           "Brand dummy"
    label var kp                 "Brand dummy"
    label var gw                 "Brand dummy"
    label var asda               "Brand dummy"
    label var tesco              "Brand dummy"
    label var other              "Brand dummy"
    label var outside1           "Outside option (unhealthy) dummy"
    label var outside2           "Outside option dummy"
    label var own_stock          "Own ad: stock"
    label var rival_stock        "Comp ad: stock"
    label var pastchoice         "Index for purchase brand before"
    label var pastmonth          "Index for purchase brand in past month"
    label var region             "Household region"

    keep  index hhno year month week agg_brand agg_manu product choice size price health_cost energy_kj saturates sodium pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco other outside1 outside2 own_stock rival_stock pastchoice pastmonth region
    order index hhno year month week agg_brand agg_manu product choice size price health_cost energy_kj saturates sodium pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco other outside1 outside2 own_stock rival_stock pastchoice pastmonth region

    sa "$P/FoodIn_Estimation_group`n'.dta",replace
}

***FOTG

foreach n of numlist 1(1)12{

    u "$P/FOTG_group`n'.dta",clear

    keep index hhno indvno year month week

    sa "$P/FOTG_index_vars_group`n'.dta",replace

    u "$P/FOTG_group`n'.dta",clear

    bysort product: keep if _n==1
    keep product agg_brand agg_manu

    sa "$P/FOTG_options_vars_group`n'.dta",replace

    u "$P/FOTG_group`n'.dta",clear

    keep index product
    gen choice = 1
    fillin index product
    drop _fillin
    replace choice=0 if choice==.

    mer m:1 index using "$P/FOTG_index_vars_group`n'.dta"
    keep if _m==3
    drop _m

    merge m:1 product using "$P/FOTG_options_vars_group`n'.dta"
    keep if _m==3
    drop _m

    mer m:1 product week using "$P/FOTG_characteristics.dta"
    drop if _m==2
    drop _m

    foreach v in price size health_cost energy_kj saturates sodium {
        replace `v' = 0 if product==999|product==199
    }

    mer m:1 hhno agg_brand week using "$PA/RGdisagg_ad_stocks.dta",keepusing(os_wads rs_wads)
    rename os_wads own_stock
    rename rs_wads rival_stock
    bysort hhno: egen max=max(_m)
    drop if max==1|max==2
    drop max
    bysort index: egen min=min(_m)
    drop if min==2
    foreach v in own_stock rival_stock {
        replace `v'=0 if agg_brand==199|agg_brand==999
    }
    drop _m min

    merge m:1 hhno week agg_brand using "$P/Experience.dta"
    drop if _m==2
    drop _m
    replace pastchoice = 0 if agg_brand==199|agg_brand==999

    merge m:1 hhno indvno week agg_brand using "$P/FOTG_habits.dta"
    drop if _m==2
    drop _m
    replace pastmonth = 0 if agg_brand==199|agg_brand==999

    merge m:1 hhno week using "$P/FoodIn_crispspurchase.dta"
    drop if _m==2
    gen fip = _m==3 & agg_brand!=199 & agg_brand!=999
    drop _m

    mer m:1 hhno using "$PA/hh_panel_tv.dta",keepusing(tvreg)
    drop if _m==2
    drop _m

    gen     region = 1 if tvreg==1|tvreg==6|tvreg==10
    replace region = 2 if tvreg==2|tvreg==8|tvreg==9
    replace region = 3 if tvreg==3|tvreg==4|tvreg==5|tvreg==7

    gen walk_reg = agg_brand==2
    gen walk_sen = agg_brand==3
    gen walk_dor = agg_brand==4
    gen walk_oth = agg_brand==5
    gen kp       = agg_brand==6
    gen gw       = agg_brand==7
    gen other    = agg_brand==10
    gen outside1 = agg_brand==199
    gen outside2 = agg_brand==999

    replace size = size*1000

    label var index              "Index of choice occasion"
    label var hhno               "Index of hh"
    label var indvno             "Index of individual"
    label var year               "Year"
    label var month              "Month"
    label var week               "Week"
    label var agg_brand          "Brand"
    label var agg_manu           "Manufacturer"
    label var product            "Product"
    label var choice             "1 for option chosen"
    label var size               "Option size in Kg"
    label var price              "Option price"
    label var health_cost        "Brand health score"
    label var energy_kj          "KJ per 100g"
    label var saturates          "g per 100g"
    label var sodium             "g per 100g"
    label var walk_reg           "Brand dummy"
    label var walk_sen           "Brand dummy"
    label var walk_dor           "Brand dummy"
    label var walk_oth           "Brand dummy"
    label var kp                 "Brand dummy"
    label var gw                 "Brand dummy"
    label var other              "Brand dummy"
    label var outside1           "Outside option (unhealthy) dummy"
    label var outside2           "Outside option dummy"
    label var own_stock          "Own ad: stock"
    label var rival_stock        "Comp ad: stock"
    label var pastchoice         "Index for purchase brand before"
    label var pastmonth          "Index for purchase brand in past month"
    label var fip                "Index for food in purchase"
    label var region             "Household region"

    keep  index hhno indvno year month week agg_brand agg_manu product choice size price health_cost energy_kj saturates sodium walk_reg walk_sen walk_dor walk_oth kp gw other outside1 outside2 own_stock rival_stock pastchoice pastmonth fip region
    order index hhno indvno year month week agg_brand agg_manu product choice size price health_cost energy_kj saturates sodium walk_reg walk_sen walk_dor walk_oth kp gw other outside1 outside2 own_stock rival_stock pastchoice pastmonth fip region

    sa "$P/FOTG_Estimation_group`n'.dta",replace
}

**************************************************************************
**M) Outsheet estimation data
**************************************************************************
log using "$P/createdata.log",replace

foreach n of numlist 1(1)11{
    u "$P/FoodIn_Estimation_group`n'.dta",clear

    egen cs = group(index)
    egen dm = group(hhno)
    egen op = group(product)
    egen mk = group(year month)

    gen othbrds = walk_sen==1|walk_dor==1|walk_oth==1|kp==1|gw==1|asda==1|tesco==1|other==1
    foreach v in pringles walk_reg othbrds outside1 {
        foreach m of numlist 2(1)17 {
            qui gen     `v'_`m' = `v' if mk==`m'
            qui replace `v'_`m' = 0 if `v'_`m'==.
        }
    }

    foreach x of numlist 1 2 3 {
        gen outside2_r`x' = outside2==1 & region==`x'
    }

    replace own_stock   = own_stock/100
    replace rival_stock = rival_stock/100

    replace own_stock   = ln(own_stock+(own_stock^2+1)^(0.5))
    replace rival_stock = ln(rival_stock+(rival_stock^2+1)^(0.5))

    gen price_own_stock       = price*own_stock
    gen health_cost_own_stock = health_cost*own_stock

    gen size_sq = (size^2)/1000
    gen wk = agg_manu==2

    replace health_cost = 20 if product==199

    keep  cs dm mk op choice price own_stock rival_stock pastchoice pastmonth size size_sq price_own_stock health_cost_own_stock pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco outside1 outside2 wk pringles_* walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost
    order cs dm mk op choice price own_stock rival_stock pastchoice pastmonth size size_sq price_own_stock health_cost_own_stock pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco outside1 outside2 wk pringles_* walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost

    sort cs op
    su
    outsheet using "$P/FoodIn_group`n'_data.raw",comma nol non replace
}

foreach n of numlist 1(1)12{
    u "$P/FOTG_Estimation_group`n'.dta",clear

    egen cs = group(index)
    egen dm = group(hhno indvno)
    egen op = group(product)
    egen mk = group(year month)

    gen othbrds = walk_sen==1|walk_dor==1|walk_oth==1|kp==1|gw==1|other==1
    foreach v in walk_reg othbrds outside1 {
        foreach m of numlist 2(1)17 {
            qui gen     `v'_`m' = `v' if mk==`m'
            qui replace `v'_`m' = 0 if `v'_`m'==.
        }
    }

    foreach x of numlist 1 2 3 {
        gen outside2_r`x' = outside2==1 & region==`x'
    }

    replace own_stock   = own_stock/100
    replace rival_stock = rival_stock/100

    replace own_stock   = ln(own_stock+(own_stock^2+1)^(0.5))
    replace rival_stock = ln(rival_stock+(rival_stock^2+1)^(0.5))

    gen price_own_stock       = price*own_stock
    gen health_cost_own_stock = health_cost*own_stock

    gen size_sq = (size^2)/1000

    replace health_cost = 20 if product==199

    keep  cs dm mk op choice price own_stock rival_stock pastchoice pastmonth fip size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost
    order cs dm mk op choice price own_stock rival_stock pastchoice pastmonth fip size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost

    sort cs op
    su
    outsheet using "$P/FOTG_group`n'_data.raw",comma nol non replace
}

**************************************************************************
**N) Outsheet computation data
**************************************************************************

****Main data

***Food in
foreach n of numlist 1(1)11{
    u "$P/FoodIn_Estimation_group`n'.dta",clear

    keep if choice==1

    bysort month: gen npurch = _N
    gen cut_off = int(npurch*0.1+0.5)

    set seed 232
    drawnorm x
    sort month x
    by month: keep if _n<cut_off

    keep hhno week

    sa "$P/FoodIn_computations_sample_`n'.dta",replace

    u "$P/FoodIn_Estimation_group`n'.dta",clear

    merge m:1 hhno week using "$P/FoodIn_computations_sample_`n'.dta"
    keep if _m==3
    drop _m

    sa "$P/FoodIn_Computations_group`n'.dta",replace

    egen cs = group(index)
    egen dm = group(hhno)
    egen op = group(product)
    egen mk = group(year month)

    gen othbrds = walk_sen==1|walk_dor==1|walk_oth==1|kp==1|gw==1|asda==1|tesco==1|other==1
    foreach v in pringles walk_reg othbrds outside1 {
        foreach m of numlist 2(1)17 {
            qui gen     `v'_`m' = `v' if mk==`m'
            qui replace `v'_`m' = 0 if `v'_`m'==.
        }
    }

    foreach x of numlist 1 2 3 {
        gen outside2_r`x' = outside2==1 & region==`x'
    }

    replace own_stock   = own_stock/100
    replace rival_stock = rival_stock/100

    replace own_stock   = ln(own_stock+(own_stock^2+1)^(0.5))
    replace rival_stock = ln(rival_stock+(rival_stock^2+1)^(0.5))

    gen price_own_stock       = price*own_stock
    gen health_cost_own_stock = health_cost*own_stock

    gen size_sq = (size^2)/1000
    gen wk = agg_manu==2

    replace health_cost = 20 if product==199

    keep  cs dm mk op choice price own_stock rival_stock pastchoice pastmonth size size_sq price_own_stock health_cost_own_stock pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco outside1 outside2 wk pringles_* walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost
    order cs dm mk op choice price own_stock rival_stock pastchoice pastmonth size size_sq price_own_stock health_cost_own_stock pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco outside1 outside2 wk pringles_* walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost

    sort cs op
    su
    outsheet using "$P/FoodIn_group`n'_comp_data.raw",comma nol non replace
}

***FOTG
foreach n of numlist 1(1)12{
    u "$P/FOTG_Estimation_group`n'.dta",clear

    keep if choice==1

    bysort month: gen npurch = _N
    gen cut_off = int(npurch*0.1+0.5)

    set seed 232
    drawnorm x
    sort month x
    by month: keep if _n<cut_off

    keep hhno indvno week

    sa "$P/FOTG_computations_sample_`n'.dta",replace

    u "$P/FOTG_Estimation_group`n'.dta",clear

    merge m:1 hhno indvno week using "$P/FOTG_computations_sample_`n'.dta"
    keep if _m==3
    drop _m

    sa "$P/FOTG_Computations_group`n'.dta",replace

    egen cs = group(index)
    egen dm = group(hhno indvno)
    egen op = group(product)
    egen mk = group(year month)

    gen othbrds = walk_sen==1|walk_dor==1|walk_oth==1|kp==1|gw==1|other==1
    foreach v in walk_reg othbrds outside1 {
        foreach m of numlist 2(1)17 {
            qui gen     `v'_`m' = `v' if mk==`m'
            qui replace `v'_`m' = 0 if `v'_`m'==.
        }
    }

    foreach x of numlist 1 2 3 {
        gen outside2_r`x' = outside2==1 & region==`x'
    }

    replace own_stock   = own_stock/100
    replace rival_stock = rival_stock/100

    replace own_stock   = ln(own_stock+(own_stock^2+1)^(0.5))
    replace rival_stock = ln(rival_stock+(rival_stock^2+1)^(0.5))

    gen price_own_stock       = price*own_stock
    gen health_cost_own_stock = health_cost*own_stock

    gen size_sq = (size^2)/1000

    replace health_cost = 20 if product==199

    keep  cs dm mk op choice price own_stock rival_stock pastchoice pastmonth fip size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost
    order cs dm mk op choice price own_stock rival_stock pastchoice pastmonth fip size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2 health_cost

    sort cs op
    su
    outsheet using "$P/FOTG_group`n'_comp_data.raw",comma nol non replace
}

****Advertising effects

u "$PA/RGdisagg_ad_stocks_ft.dta",clear

rename os_wads own_stock
rename rs_wads rival_stock

sort hhno agg_brand week
by hhno agg_brand: gen own_stock_cf = (0.9^4)*own_stock[_n-4]

keep if week>21
drop if week>95
replace week = week - 21

keep hhno week agg_brand own_stock_cf

sa "$P/ad_effects_cf.dta",replace

u "$P/FoodIn_Computations_group1.dta",clear
gen R = 1
foreach n of numlist 2(1)11 {
    append using "$P/FoodIn_Computations_group`n'.dta"
    replace R = `n' if R==.
}

egen cs = group(R index)
egen dm = group(R hhno)
egen op = group(product)
egen br = group(agg_brand)
egen mk = group(year month)

merge m:1 hhno week agg_brand using "$P/ad_effects_cf.dta"
bysort hhno: egen max=max(_m)
drop if max==2
drop max
bysort index: egen min=min(_m)
drop if min==2
replace own_stock_cf=0 if agg_brand==199|agg_brand==999
drop _m min

keep cs dm op mk br own_stock own_stock_cf
order cs dm op mk br own_stock own_stock_cf

replace own_stock    = own_stock/100
replace own_stock_cf = own_stock_cf/100

sort cs op
su
outsheet using "$P/FoodIn_ad_effects_cf.raw",comma nol non replace

u "$P/FOTG_Computations_group1.dta",clear
gen R = 1
foreach n of numlist 2(1)12 {
    append using "$P/FOTG_Computations_group`n'.dta"
    replace R = `n' if R==.
}

egen cs = group(R index)
egen dm = group(R hhno indvno)
egen op = group(product)
egen br = group(agg_brand)
egen mk = group(year month)

merge m:1 hhno week agg_brand using "$P/ad_effects_cf.dta"
bysort hhno: egen max=max(_m)
drop if max==2
drop max
bysort index: egen min=min(_m)
drop if min==2
replace own_stock_cf=0 if agg_brand==199|agg_brand==999
drop _m min

keep cs dm op mk br own_stock own_stock_cf
order cs dm op mk br own_stock own_stock_cf

replace own_stock    = own_stock/100
replace own_stock_cf = own_stock_cf/100

sort cs op
su
outsheet using "$P/FOTG_ad_effects_cf.raw",comma nol non replace

****Ownership structure

u "$P/FoodIn_Estimation_group1.dta",clear

egen op = group(product)
egen man = group(agg_manu)
egen br = group(agg_brand)

bysort op: keep if _n==1

keep  op br man
order op br man
tab man,gen(mm)

sort op

outsheet using "$P/FoodIn_firm_data.raw",comma nol non replace

u "$P/FOTG_Estimation_group1.dta",clear

egen op = group(product)
egen man = group(agg_manu)
egen br = group(agg_brand)

bysort op: keep if _n==1

keep  op br man
order op br man
tab man,gen(mm)

sort op

outsheet using "$P/FOTG_firm_data.raw",comma nol non replace

****Collusion - ownership structure

u "$P/FoodIn_Estimation_group1.dta",clear

egen op = group(product)
egen br = group(agg_brand)

bysort op: keep if _n==1

gen     man = 1
replace man = 2 if op==27
replace man = 3 if op==28
keep  op br man
order op br man
tab man,gen(mm)

sort op

outsheet using "$P/FoodIn_collude_data.raw",comma nol non replace


log close

**************************************************************************
**O) Estimate conditional logits
**************************************************************************
log using "$P/clogits.log",replace

foreach n of numlist 1(1)11{
    u "$P/FoodIn_Estimation_group`n'.dta",clear

    egen mk = group(year month)

    gen othbrds = walk_sen==1|walk_dor==1|walk_oth==1|kp==1|gw==1|asda==1|tesco==1|other==1
    foreach v in pringles walk_reg othbrds outside1 {
        foreach m of numlist 2(1)17 {
            qui gen     `v'_`m' = `v' if mk==`m'
            qui replace `v'_`m' = 0 if `v'_`m'==.
        }
    }

    foreach n of numlist 1 2 3 {
        gen outside2_r`n' = outside2==1 & region==`n'
    }

    replace own_stock   = own_stock/100
    replace rival_stock = rival_stock/100

    replace own_stock   = ln(own_stock+(own_stock^2+1)^(0.5))
    replace rival_stock = ln(rival_stock+(rival_stock^2+1)^(0.5))

    gen price_own_stock       = price*own_stock
    gen health_cost_own_stock = health_cost*own_stock

    gen size_sq = (size^2)/1000

    disp "`n'"

    clogit choice price            own_stock rival_stock size size_sq price_own_stock health_cost_own_stock pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco outside1 outside2 pringles_* walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2,group(index)
    clogit choice price pastchoice own_stock rival_stock size size_sq price_own_stock health_cost_own_stock pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco outside1 outside2 pringles_* walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2,group(index)
    clogit choice price pastmonth  own_stock rival_stock size size_sq price_own_stock health_cost_own_stock pringles walk_reg walk_sen walk_dor walk_oth kp gw asda tesco outside1 outside2 pringles_* walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2,group(index)

}

foreach n of numlist 1(1)12{
    u "$P/FOTG_Estimation_group`n'.dta",clear

    egen mk = group(year month)

    gen othbrds = walk_sen==1|walk_dor==1|walk_oth==1|kp==1|gw==1|other==1
    foreach v in walk_reg othbrds outside1 {
        foreach m of numlist 2(1)17 {
            qui gen     `v'_`m' = `v' if mk==`m'
            qui replace `v'_`m' = 0 if `v'_`m'==.
        }
    }

    foreach n of numlist 1 2 3 {
        gen outside2_r`n' = outside2==1 & region==`n'
    }

    replace own_stock   = own_stock/100
    replace rival_stock = rival_stock/100

    replace own_stock   = ln(own_stock+(own_stock^2+1)^(0.5))
    replace rival_stock = ln(rival_stock+(rival_stock^2+1)^(0.5))

    gen price_own_stock       = price*own_stock
    gen health_cost_own_stock = health_cost*own_stock

    gen size_sq = (size^2)/1000

    disp "`n'"

    clogit choice price            own_stock rival_stock size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2,group(index)
    clogit choice price pastchoice own_stock rival_stock size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2,group(index)
    clogit choice price pastmonth  own_stock rival_stock size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2,group(index)
    clogit choice price fip        own_stock rival_stock size size_sq price_own_stock health_cost_own_stock walk_reg walk_sen walk_dor walk_oth kp gw outside1 outside2 walk_reg_* othbrds_* outside1_* outside2_r1 outside2_r2,group(index)

}

log close
